@@ -7,11 +7,13 @@
 
 
 enum {
+  SPVM_ATTRIBUTE_C_ID_UNKNOWN,
   SPVM_ATTRIBUTE_C_ID_MULNUM_T,
   SPVM_ATTRIBUTE_C_ID_POINTER_T,
   SPVM_ATTRIBUTE_C_ID_NATIVE,
   SPVM_ATTRIBUTE_C_ID_PRECOMPILE,
   SPVM_ATTRIBUTE_C_ID_PUBLIC,
+  SPVM_ATTRIBUTE_C_ID_PROTECTED,
   SPVM_ATTRIBUTE_C_ID_PRIVATE,
   SPVM_ATTRIBUTE_C_ID_RW,
   SPVM_ATTRIBUTE_C_ID_RO,
